@@ -2,7 +2,7 @@ import sys
 if sys.platform == 'win32':
     import ftd600._ftd3xx_win32 as _ft
 elif sys.platform == 'linux':
-    import _ftd3xx_linux as _ft	
+    import ftd600._ftd3xx_linux as _ft	
 import ctypes as c
 import threading
 import time
